/*
 * modules.h
 * 
 * Copyright (C) 2006  Josef Kufner <jk@myserver.cz>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 */
#ifndef JK_MODULES_H
#define JK_MODULES_H

#include <sys/types.h>
#include <unistd.h>

enum {
	CB_INITIALIZE, CB_CLEANUP,
	CB_TIMEOUT, CB_FILEDESCRIPTOR,
	CB_GET_TIMEOUT_PTR, CB_GET_FD_LIST_PTR,
	CB_MAX
};

extern const char *cb_name[CB_MAX + 1];

struct s_mod_info {
	/* about module */
	char *name;
	char *real_name;
	int var_offset;
	char *args;
	void *data;

	/* dl things */
	void *dlh;

	/* callback pointers */
	void *callback[CB_MAX];

	/* config. vars */
	void *cfg_fd;
	int *cfg_fd_old;
	void *cfg_timeout;
	int *cfg_timeout_always;

};

typedef struct s_module {
	struct s_mod_info *info;
	int info_count;
	char *path;
} MODULE;


MODULE * module_init(char *path);
void module_destroy(MODULE *mod);

int module_configure(MODULE *mod, char *mod_name, int var_offset, char *args);
int module_load(MODULE *mod, int mod_id);
int module_load_config(MODULE *mod);
int module_remove(MODULE *mod, int mod_id);

int module_load_all(MODULE *mod);
void module_remove_all(MODULE *mod);

/* call callback */
int module_callback(MODULE *mod, int mod_id, int callback, ...);

/* event handlers -- called from main loop */
long long module_handle_timeout(MODULE *mod, long long timeout_duration, int important_only, int force_nonimportant);
void module_handle_fds(MODULE *mod, fd_set *s);
int module_fill_fdset(MODULE *mod, fd_set *s);

#endif

