/*
 * wmcdclock.c - icebuteo module 'clock'
 * 
 * Copyright (C) 2006  Josef Kufner <jk@myserver.cz>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 */

#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <string.h>
#include <stdio.h>

#include "wmcdclock.h"

#define DEBUG 10
#include "debug.h"

#define mod_name "wmcdclock"

int open_fifo(char *fifo_name) {
	int fifo_fd;

	DBG_MSG(1, "open_fifo");
	if (mkfifo(fifo_name, 0600) != 0) {
		perror(fifo_name);
		return -1;
	}
	if ((fifo_fd = open(fifo_name, O_RDONLY | O_NONBLOCK)) == -1) {
		perror(fifo_name);
		return -1;
	}
	return fifo_fd;
}

int close_fifo(char *fifo_name, int fifo_fd) {
	DBG_MSG(1, "close_fifo");
	if (close(fifo_fd) == -1) {
		perror(fifo_name);
		return 0;
	}
	if (unlink(fifo_name) != 0) {
		perror(fifo_name);
		return 0;
	}
	return 1;
}

int reopen_fifo(char *fifo_name, int old_fifo_fd) {
	int fifo_fd;
	DBG_MSG(1, "reopen_fifo");
	if (close(old_fifo_fd) == -1) {
		perror(fifo_name);
		return -1;
	}
	if ((fifo_fd = open(fifo_name, O_RDONLY | O_NONBLOCK)) == -1) {
		perror(fifo_name);
		return -1;
	}
	return fifo_fd;
}

int parse_fifo(char *buf, time_t *count_down_time) {
	int sec, min, hour;
	char cmd;
	struct tm *set;
	time_t set_ts;

	DBG_MSG(1, "parse_fifo");
	if (sscanf(buf, "%c%02d:%02d:%02d", &cmd, &hour, &min, &sec) != 4 && cmd != '+' && cmd != '=') {
		fprintf(stderr, "wmcdclock: wrong command -- must be [+=]HH:MM:SS\n");
		return 0;
	}

	set_ts = time(NULL);
	if (cmd == '=') {
		set = localtime(&set_ts);
		set->tm_mday += (hour < set->tm_hour);
		set->tm_hour = hour;
		set->tm_min = min;
		set->tm_sec = sec;
	} else if (cmd == '+') {
		set = localtime(&set_ts);
		set->tm_hour += hour;
		set->tm_min += min;
		set->tm_sec += sec;
	}
	*count_down_time = mktime(set);
	return 1;
}

