/*
 * parser.h
 * 
 * Copyright (C) 2006  Josef Kufner <jk@myserver.cz>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 */
#ifndef JK_PARSER_H
#define JK_PARSER_H

#include <stdio.h>

/* token types */
#define P_INTEGER	0x0001
#define P_STRING	0x0002
#define P_FLOAT		0x0004
#define P_CONSTANT	0x0008
#define P_NOTHING	0x0010
#define P_EQUAL		0x0020
#define P_EOL		0x1000

typedef int P_FORMAT;

typedef struct {
	int type;
	char *val;		/* always set */
	int val_int;		/* set when type is numeric or P_NOTHING */
	float val_float;	/* set when type is numeric or P_NOTHING */
} P_TOKEN;

typedef struct {
	P_TOKEN *token;
	int size;
	long line;
} P_LINE;

typedef struct {
	char *str;
	int id;
	void *var;
	P_FORMAT type;
} P_TRANS;

P_LINE *parse_line(const char *filename, const FILE *f, P_FORMAT *format, int format_len);
void parse_free_line(P_LINE *ln);
int parse_set_var_by_name(const P_TRANS *def, size_t def_len, const char *name, void *var, P_FORMAT var_type, int use_free);
#define parse_string_to_int(def, def_len, str) parse_set_var_by_name(def, def_len, str, (void *) 0, 0, 0)
int parse_file(const char *filename, const FILE *f, P_FORMAT *format, int format_len,
		int symbol_pos, int value_pos, const P_TRANS *def, size_t def_len);

#endif

