/*
 * parser.lex
 * 
 * Copyright (C) 2006  Josef Kufner <jk@myserver.cz>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 */
%{
#include <assert.h>

#include "icebuteo.h"
#include "parser.h"
#include "parser-lex.h"

#undef YY_DECL
#define YY_DECL int parser_lex_scan(const char *filename)

%}

%%

[a-zA-Z_][a-zA-Z_-]*			{ return P_CONSTANT; }
[+-]?[0-9]+				{ return P_INTEGER; }
\"(\\\"|[^\"])*\"			{ return P_STRING; }
[+-]?([0-9]*\.[0-9]+|[0-9]+\.[0-9]*)	{ return P_FLOAT; }
\r?\n					{ return P_EOL; }
\-					{ return P_NOTHING; }
=					{ return P_EQUAL; }

\#[^\n]*		/* eat up comments */
[ \t]+			/* white space */

[^ \t\n]+		{
			fprintf(stderr, "%s: %d: Unrecognized word \"%s\"\n", filename, yylineno, yytext);
			return -1;
			}
%%

int yywrap(void) {
	return 1;
}



